@@ -17,8 +17,6 @@
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#define _BSD_SOURCE
-
 #include <unistd.h>
 #include <string.h>
 
@@ -37,7 +35,7 @@ static GList *cd_NetworkMonitor_get_connections_for_access_point (const gchar *c
 	for (i = 0; i < paConnections->len; i++)
 	{
 		cConnection = (gchar *)g_ptr_array_index(paConnections, i);
-		cd_debug (" Connection path : %s\n", cConnection);
+		cd_debug (" Connection path : %s", cConnection);
 		
 		pSettings = g_ptr_array_index (paSettings, i);
 		
@@ -50,7 +48,7 @@ static GList *cd_NetworkMonitor_get_connections_for_access_point (const gchar *c
 		if (v && G_VALUE_HOLDS_STRING (v))
 		{
 			cType = g_value_get_string (v);
-			cd_debug (" type : %s\n", cType);
+			cd_debug (" type : %s", cType);
 		}
 		if (cType == NULL || strcmp (cType, "802-11-wireless") != 0)  // on veut du wifi.
 			continue;
@@ -60,7 +58,7 @@ static GList *cd_NetworkMonitor_get_connections_for_access_point (const gchar *c
 		if (v && G_VALUE_HOLDS_STRING (v))
 		{
 			cID = g_value_get_string (v);
-			cd_debug (" id : %s\n", cID);
+			cd_debug (" id : %s", cID);
 		}
 		
 		pSubSettings = g_hash_table_lookup (pSettings, "802-11-wireless");
@@ -71,7 +69,7 @@ static GList *cd_NetworkMonitor_get_connections_for_access_point (const gchar *c
 		if (v && G_VALUE_HOLDS_STRING (v))
 		{
 			cMode = g_value_get_string (v);
-			cd_debug (" mode : %s\n", cMode);
+			cd_debug (" mode : %s", cMode);
 		}
 		if (iMode && cMode)
 		{
@@ -86,8 +84,8 @@ static GList *cd_NetworkMonitor_get_connections_for_access_point (const gchar *c
 		if (v && G_VALUE_HOLDS_BOXED (v))
 		{
 			GByteArray *a = g_value_get_boxed (v);
-			cAPSsid = g_strndup (a->data, a->len);
-			cd_debug (" ssid : %s\n", cSsid);
+			cAPSsid = g_strndup ((gchar *) a->data, a->len);
+			cd_debug (" ssid : %s", cSsid);
 		}
 		if (cSsid == NULL || (cAPSsid != NULL && strcmp (cAPSsid, cSsid) != 0))  // le SSID est necessaire.
 			continue;
@@ -97,7 +95,7 @@ static GList *cd_NetworkMonitor_get_connections_for_access_point (const gchar *c
 		if (v && G_VALUE_HOLDS_STRING (v))
 		{
 			cMacAddress = g_value_get_string (v);
-			cd_debug (" mac address : %s\n", cMacAddress);
+			cd_debug (" mac address : %s", cMacAddress);
 		}
 		if (cHwAddress != NULL && cMacAddress != NULL && strcmp (cMacAddress, cHwAddress) != 0)
 			continue;
@@ -115,6 +113,7 @@ static GList *cd_NetworkMonitor_get_connections_for_access_point (const gchar *c
 	return pConnList;
 }
 
+/* Not used
 static GList *cd_NetworkMonitor_get_connections_for_wired_device (const gchar *cDevice, const gchar *cHwAddress, GPtrArray *paConnections)
 {
 	GList *pConnList = NULL;
@@ -124,13 +123,13 @@ static GList *cd_NetworkMonitor_get_connections_for_wired_device (const gchar *c
 	for (i = 0; i < paConnections->len; i++)
 	{
 		cConnection = (gchar *)g_ptr_array_index(paConnections, i);
-		cd_debug (" Connection path : %s\n", cConnection);
+		cd_debug (" Connection path : %s", cConnection);
 		
 	}
 	
 	return pConnList;
 }
-
+*/
 
 static void _on_select_access_point (GtkMenuItem *menu_item, CDMenuItemData *pItemData)
 {
@@ -192,7 +191,7 @@ static void _on_select_access_point (GtkMenuItem *menu_item, CDMenuItemData *pIt
 	}
 	else
 	{
-		cd_debug ("on a choisit (%s; %s; %s)\n", pItemData->cAccessPoint, pItemData->cDevice, pItemData->cConnection);
+		cd_debug ("on a choisit (%s; %s; %s)", pItemData->cAccessPoint, pItemData->cDevice, pItemData->cConnection);
 		
 		//ActivateConnection ( s: service_name, o: connection, o: device, o: specific_object )o
 		GError *erreur = NULL;
@@ -214,7 +213,7 @@ static void _on_select_access_point (GtkMenuItem *menu_item, CDMenuItemData *pIt
 			g_error_free (erreur);
 			return ;
 		}
-		cd_debug (" => new active connection path : %s\n", cNewActiveConnectionPath);
+		cd_debug (" => new active connection path : %s", cNewActiveConnectionPath);
 	}
 }
 
@@ -226,7 +225,7 @@ GtkWidget * cd_NetworkMonitor_build_menu_with_access_points (void)
 		"/org/freedesktop/NetworkManagerSettings",
 		"org.freedesktop.NetworkManagerSettings");
 	GPtrArray *paConnections = cairo_dock_dbus_get_array (dbus_proxy_Settings, "ListConnections");
-	cd_debug ("%d connection(s)\n", paConnections ? paConnections->len : 0);
+	cd_debug ("%d connection(s)", paConnections ? paConnections->len : 0);
 	g_object_unref (dbus_proxy_Settings);
 	
 	GPtrArray *paSettings = NULL;
@@ -242,7 +241,7 @@ GtkWidget * cd_NetworkMonitor_build_menu_with_access_points (void)
 		for (i = 0; i < paConnections->len; i++)
 		{
 			cConnection = (gchar *)g_ptr_array_index(paConnections, i);
-			cd_debug (" Connection path : %s\n", cConnection);
+			cd_debug (" Connection path : %s", cConnection);
 			
 			dbus_proxy_ConnectionSettings = cairo_dock_create_new_system_proxy (
 				"org.freedesktop.NetworkManagerUserSettings",
@@ -269,9 +268,9 @@ GtkWidget * cd_NetworkMonitor_build_menu_with_access_points (void)
 	//\_____________ On recupere la liste des devices.
 	GPtrArray *paDevices = cairo_dock_dbus_get_array (myData.dbus_proxy_NM, "GetDevices");
 	g_return_val_if_fail (paDevices != NULL, FALSE);
-	cd_debug ("%d device(s)\n", paDevices->len);
+	cd_debug ("%d device(s)", paDevices->len);
 	
-	GtkWidget *pMenu = gtk_menu_new ();
+	GtkWidget *pMenu = gldi_menu_new (myIcon);
 	
 	//\_____________ On parcourt tous les devices.
 	GHashTable *pSsidTable = g_hash_table_new_full (g_str_hash,
@@ -281,7 +280,7 @@ GtkWidget * cd_NetworkMonitor_build_menu_with_access_points (void)
 	gchar *cDevice;
 	DBusGProxy *dbus_proxy_Device_prop;
 	guint iDeviceType;
-	DBusGProxy *dbus_proxy_WirelessDevice, *dbus_proxy_WiredDevice;
+	DBusGProxy *dbus_proxy_WirelessDevice;
 	DBusGProxy *dbus_proxy_AccessPoint_prop;
 	gchar *cAccessPointPath;
 	GHashTable *hProperties;
@@ -289,9 +288,7 @@ GtkWidget * cd_NetworkMonitor_build_menu_with_access_points (void)
 	gint iPercent;
 	gchar *cSsid = NULL;
 	const gchar *cHwAddress;
-	int iMode, iWirelessCapabilities;
 	CDMenuItemData *pItemData;
-	GtkWidget *pHBox;
 	uint i, j;
 	for (i = 0; i < paDevices->len; i++)
 	{
@@ -303,11 +300,11 @@ GtkWidget * cd_NetworkMonitor_build_menu_with_access_points (void)
 			"org.freedesktop.DBus.Properties");
 		if (!DBUS_IS_G_PROXY (dbus_proxy_Device_prop))
 			continue;
-		cd_debug (" device %s\n", cDevice);
+		cd_debug (" device %s", cDevice);
 		
 		// on regarde son type.
 		iDeviceType = cairo_dock_dbus_get_property_as_uint (dbus_proxy_Device_prop, "org.freedesktop.NetworkManager.Device", "DeviceType");  // 1 : ethernet, 2 : wifi
-		cd_debug (" device type : %d\n", iDeviceType);
+		cd_debug (" device type : %d", iDeviceType);
 		if (iDeviceType != 1 && iDeviceType != 2)  // ne nous insteresse pas.
 		{
 			cd_debug (" useless device type\n");
@@ -320,12 +317,11 @@ GtkWidget * cd_NetworkMonitor_build_menu_with_access_points (void)
 			// On recupere ses proprietes.
 			hProperties = cairo_dock_dbus_get_all_properties (dbus_proxy_Device_prop, "org.freedesktop.NetworkManager.Device.Wireless");
 			
-			const gchar *cAccessPointHwAdress = NULL;
-			v = (GValue *)g_hash_table_lookup (hProperties, "HwAddress");
+			/*v = (GValue *)g_hash_table_lookup (hProperties, "HwAddress");
 			if (v && G_VALUE_HOLDS_STRING (v))
 			{
 				cAccessPointHwAdress = g_value_get_string (v);
-			}
+			}*/
 			
 			int iMode = 0;
 			v = (GValue *)g_hash_table_lookup (hProperties, "Mode");
@@ -399,7 +395,7 @@ GtkWidget * cd_NetworkMonitor_build_menu_with_access_points (void)
 				if (v != NULL && G_VALUE_HOLDS_BOXED (v))
 				{
 					GByteArray *a = g_value_get_boxed (v);
-					cSsid = g_strndup (a->data, a->len);
+					cSsid = g_strndup ((gchar *) a->data, a->len);
 				}
 				
 				// on empeche les doublons.
@@ -440,7 +436,7 @@ GtkWidget * cd_NetworkMonitor_build_menu_with_access_points (void)
 					iWirelessCapabilities = g_value_get_uint (v);
 				}
 				
-				cd_debug ("%d) %s : %s (%s, %d%%)\n", j, cSsid, cAccessPointPath, cHwAddress, iPercent);
+				cd_debug ("%d) %s : %s (%s, %d%%)", j, cSsid, cAccessPointPath, cHwAddress, iPercent);
 				
 				const gchar *cImage = NULL;
 				if (iPercent > 80)
@@ -463,7 +459,7 @@ GtkWidget * cd_NetworkMonitor_build_menu_with_access_points (void)
 				// on cherche une connection qui convienne.
 				GList *pConnList = cd_NetworkMonitor_get_connections_for_access_point (cAccessPointPath, cDevice, cSsid, cHwAddress, iMode, iWirelessCapabilities, paConnections, paSettings);
 				
-				cd_debug ("%d connexion(s) satisfont a ce point d'acces\n", g_list_length (pConnList));
+				cd_debug ("%d connexion(s) satisfont a ce point d'acces", g_list_length (pConnList));
 				
 				if (pConnList == NULL || pConnList->next == NULL)
 				{
