@@ -23,10 +23,10 @@
 
 #include <cairo-dock.h>
 
-void cd_sysmonitor_get_data (CairoDockModuleInstance *myApplet);
+void cd_sysmonitor_get_data (GldiModuleInstance *myApplet);
 
-gboolean cd_sysmonitor_update_from_data (CairoDockModuleInstance *myApplet);
+gboolean cd_sysmonitor_update_from_data (GldiModuleInstance *myApplet);
 
-void cd_sysmonitor_format_value (CairoDataRenderer *pRenderer, int iNumValue, gchar *cFormatBuffer, int iBufferLength, CairoDockModuleInstance *myApplet);
+void cd_sysmonitor_format_value (CairoDataRenderer *pRenderer, int iNumValue, gchar *cFormatBuffer, int iBufferLength, GldiModuleInstance *myApplet);
 
 #endif
