@@ -43,8 +43,25 @@ static void _cd_musicplayer_stop (GtkMenuItem *menu_item, gpointer *data) {
 static void _cd_musicplayer_next (GtkMenuItem *menu_item, gpointer *data) {
 	myData.pCurrentHandler->control (PLAYER_NEXT, NULL);
 }
-static void _cd_musicplayer_show_from_systray (GtkMenuItem *menu_item, gpointer *data) {
-	cairo_dock_launch_command (myData.pCurrentHandler->launch);
+static void _cd_musicplayer_show_from_systray (GtkMenuItem *menu_item, gpointer *data)
+{
+	gboolean bRaised = FALSE;
+	if (myData.pCurrentHandler->raise)
+		bRaised = myData.pCurrentHandler->raise ();
+	if (! bRaised && myData.pCurrentHandler->pAppInfo)
+		gldi_app_info_launch (myData.pCurrentHandler->pAppInfo, NULL);
+}
+static void _cd_musicplayer_quit (GtkMenuItem *menu_item, gpointer *data)
+{
+	gboolean bQuit = FALSE;
+	if (myData.pCurrentHandler->quit)
+		bQuit = myData.pCurrentHandler->quit ();
+	if (! bQuit)
+	{ //!!! TODO
+/*		gchar *cmd = g_strdup_printf ("killall %s", myData.pCurrentHandler->launch);
+		cairo_dock_launch_command (cmd);
+		g_free (cmd); */
+	}
 }
 static void _cd_musicplayer_jumpbox (GtkMenuItem *menu_item, gpointer *data) {
 	myData.pCurrentHandler->control (PLAYER_JUMPBOX, NULL);
@@ -60,11 +77,12 @@ static void _cd_musicplayer_rate (GtkMenuItem *menu_item, gpointer *data) {
 }
 static void _cd_musicplayer_info (GtkMenuItem *menu_item, gpointer *data)
 {
-	cd_musicplayer_popup_info ();
+	// the user wants to see this dialogue, it's maybe better to not remove it automatically
+	cd_musicplayer_popup_info (0); // 0 = without any timeout
 }
 static void _cd_musicplayer_launch (GtkMenuItem *menu_item, gpointer *data)
 {
-	cairo_dock_launch_command (myData.pCurrentHandler->launch);
+	gldi_app_info_launch (myData.pCurrentHandler->pAppInfo, NULL);
 }
 
 static void _cd_musicplayer_choose_player (GtkMenuItem *menu_item, gpointer *data)
@@ -80,13 +98,13 @@ static void _cd_musicplayer_find_player (GtkMenuItem *menu_item, gpointer *data)
 	MusicPlayerHandler *pHandler = cd_musicplayer_dbus_find_opened_player ();
 	if (pHandler == NULL)
 	{
-		cairo_dock_show_temporary_dialog_with_icon (D_("Sorry, I couldn't detect any player.\nIf it is running, it is maybe because its version is too old and does not offer such service."),
+		gldi_dialog_show_temporary_with_icon (D_("Sorry, I couldn't detect any player.\nIf it is running, it is maybe because its version is too old and does not offer such service."),
 			myIcon,
 			myContainer,
 			7000,
 			MY_APPLET_SHARE_DATA_DIR"/"MY_APPLET_ICON_FILE);
 	}
-	else if (pHandler != myData.pCurrentHandler)
+	else if (pHandler != myData.pCurrentHandler || !strcmp (pHandler->name, "Mpris2"))
 	{
 		if (myData.pCurrentHandler != NULL)
 		{
@@ -95,8 +113,8 @@ static void _cd_musicplayer_find_player (GtkMenuItem *menu_item, gpointer *data)
 		
 		// get the name of the running player.
 		const gchar *cPlayerName;
-		if (strcmp (pHandler->name, "Mpris2") == 0)  // generic MPRIS2 handler, use the program name.
-			cPlayerName = pHandler->launch;
+		if (strcmp (pHandler->name, "Mpris2") == 0)  // generic MPRIS2 handler, use the class.
+			cPlayerName = pHandler->appclass;
 		else
 			cPlayerName = pHandler->name;
 		cd_debug ("found %s (%s)", pHandler->name, cPlayerName);
@@ -104,8 +122,12 @@ static void _cd_musicplayer_find_player (GtkMenuItem *menu_item, gpointer *data)
 		// write it down into our conf file
 		cairo_dock_update_conf_file (CD_APPLET_MY_CONF_FILE,
 			G_TYPE_STRING, "Configuration", "current-player", cPlayerName,
+			G_TYPE_STRING, "Configuration", "desktop-entry", "",  // reset the desktop filename, we'll get the new one from the "DesktopEntry" property of the new player
 			G_TYPE_INVALID);
+		g_free (myConfig.cMusicPlayer);
 		myConfig.cMusicPlayer = g_strdup (cPlayerName);
+		g_free (myConfig.cLastKnownDesktopFile);
+		myConfig.cLastKnownDesktopFile = NULL;
 		
 		// set the handler with this value.
 		cd_musicplayer_set_current_handler (myConfig.cMusicPlayer);
@@ -124,34 +146,30 @@ static void _choice_dialog_action (int iClickedButton, GtkWidget *pInteractiveWi
 	if (cPlayerName == NULL || *cPlayerName == '\0')
 		return;
 	// write it down into our conf file
-	cairo_dock_update_conf_file (myApplet->cConfFilePath,
+	cairo_dock_update_conf_file (CD_APPLET_MY_CONF_FILE,
 		G_TYPE_STRING, "Configuration", "current-player", cPlayerName,
+		G_TYPE_STRING, "Configuration", "desktop-entry", "",  // reset the desktop filename, we'll get the new one from the "DesktopEntry" property of the new player
 		G_TYPE_INVALID);
+	g_free (myConfig.cMusicPlayer);
 	myConfig.cMusicPlayer = g_strdup (cPlayerName);
+	g_free (myConfig.cLastKnownDesktopFile);
+	myConfig.cLastKnownDesktopFile = NULL;
 	// set the handler with this value.
 	cd_musicplayer_set_current_handler (myConfig.cMusicPlayer);
 	// launch it, if it's already running, it's likely to have no effect
-	cairo_dock_launch_command (myData.pCurrentHandler->launch);
+	gldi_app_info_launch (myData.pCurrentHandler->pAppInfo, NULL);
 }
 static void _show_players_list_dialog (void)
 {
 	// build a list of the available groups.
-	#if (GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 24)
-	GtkWidget *pComboBox = gtk_combo_box_entry_new_text ();
-	#else
 	GtkWidget *pComboBox = gtk_combo_box_text_new_with_entry ();
-	#endif
 	GList *h;
 	MusicPlayerHandler *handler;
 	for (h = myData.pHandlers; h != NULL; h = h->next)
 	{
 		handler = h->data;
 		if (handler->cMprisService != NULL)
-			#if (GTK_MAJOR_VERSION < 3 && GTK_MINOR_VERSION < 24)
-			gtk_combo_box_append_text (GTK_COMBO_BOX (pComboBox), handler->name);
-			#else
 			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (pComboBox), handler->name);
-			#endif
 	}
 	GtkTreeModel *pModel = gtk_combo_box_get_model (GTK_COMBO_BOX (pComboBox));
 	if (pModel)
@@ -163,15 +181,15 @@ static void _show_players_list_dialog (void)
 	if (pRunningHandler != NULL)
 	{
 		GtkWidget *pEntry = gtk_bin_get_child (GTK_BIN (pComboBox));
-		if (strcmp (pRunningHandler->name, "Mpris2") == 0)  // generic MPRIS2 handler, use the program name.
-			gtk_entry_set_text (GTK_ENTRY (pEntry), pRunningHandler->launch);
+		if (strcmp (pRunningHandler->name, "Mpris2") == 0)  // generic MPRIS2 handler, use the app class.
+			gtk_entry_set_text (GTK_ENTRY (pEntry), pRunningHandler->appclass);
 		else
 			gtk_entry_set_text (GTK_ENTRY (pEntry), pRunningHandler->name);
 	}
 
 	// build the dialog.
-	CairoDialogAttribute attr;
-	memset (&attr, 0, sizeof (CairoDialogAttribute));
+	CairoDialogAttr attr;
+	memset (&attr, 0, sizeof (CairoDialogAttr));
 	attr.cText = D_("Choose a music player to control");
 	attr.cImageFilePath = NULL;
 	attr.pInteractiveWidget = pComboBox;
@@ -180,8 +198,10 @@ static void _show_players_list_dialog (void)
 	attr.pFreeDataFunc = (GFreeFunc)NULL;
 	const gchar *cButtons[] = {"ok", "cancel", NULL};
 	attr.cButtonsImage = cButtons;
+	attr.pIcon = myIcon;
+	attr.pContainer = myContainer;
 
-	cairo_dock_build_dialog (&attr, myIcon, myContainer);
+	gldi_dialog_new (&attr);
 }
 
 //\___________ Define here the action to be taken when the user left-clicks on your icon or on its subdock or your desklet. The icon and the container that were clicked are available through the macros CD_APPLET_CLICKED_ICON and CD_APPLET_CLICKED_CONTAINER. CD_APPLET_CLICKED_ICON may be NULL if the user clicked in the container but out of icons.
@@ -197,9 +217,12 @@ CD_APPLET_ON_CLICK_BEGIN
 				{
 					_cd_musicplayer_pp (NULL, NULL);
 				}
-				else if (myData.pCurrentHandler->launch != NULL)
+				else
 				{
-					cairo_dock_launch_command (myData.pCurrentHandler->launch);
+					if (myIcon->cClass != NULL)
+						gldi_icon_launch_command (myIcon);
+					else if (myData.pCurrentHandler->pAppInfo)
+						gldi_app_info_launch (myData.pCurrentHandler->pAppInfo, NULL);
 				}
 			}
 			else if (myData.mouseOnButton2)
@@ -212,18 +235,23 @@ CD_APPLET_ON_CLICK_BEGIN
 				{
 					if (myData.pCurrentHandler->iPlayerControls & PLAYER_JUMPBOX)
 						_cd_musicplayer_jumpbox (NULL, NULL);
-					else if (myIcon->Xid != 0)
-						cairo_dock_show_xwindow (myIcon->Xid);
+					else if (myIcon->pAppli != NULL)
+						gldi_window_show (myIcon->pAppli);
 				}
-				else if (myData.pCurrentHandler->launch != NULL)
-					cairo_dock_launch_command (myData.pCurrentHandler->launch);
+				else if (myData.pCurrentHandler->pAppInfo)
+					gldi_app_info_launch (myData.pCurrentHandler->pAppInfo, NULL);
 			}
 			else
 			{
 				if(myData.bIsRunning)
-					cd_musicplayer_popup_info ();
-				else if (myData.pCurrentHandler->launch != NULL)
-					cairo_dock_launch_command (myData.pCurrentHandler->launch);
+					cd_musicplayer_popup_info (myConfig.iDialogDuration);
+				else
+				{
+					if (myIcon->cClass != NULL)
+						gldi_icon_launch_command (myIcon);
+					else if (myData.pCurrentHandler->pAppInfo)
+						gldi_app_info_launch (myData.pCurrentHandler->pAppInfo, NULL);
+				}
 			}
 		}
 		else  // pas de boutons.
@@ -234,18 +262,25 @@ CD_APPLET_ON_CLICK_BEGIN
 				{
 					_cd_musicplayer_pp (NULL, NULL);
 				}
-				else if (myIcon->Xid != 0)
+				else if (myIcon->pAppli != NULL)
 				{
-					if (myIcon->Xid == cairo_dock_get_current_active_window ())  // la fenetre du lecteur a le focus. en mode desklet ca ne marche pas car il aura pris le focus au moment du clic.
-						cairo_dock_minimize_xwindow (myIcon->Xid);
+					if (myIcon->pAppli == gldi_windows_get_active ())  // la fenetre du lecteur a le focus. en mode desklet ca ne marche pas car il aura pris le focus au moment du clic.
+						gldi_window_minimize (myIcon->pAppli);
 					else
-						cairo_dock_show_xwindow (myIcon->Xid);
+						gldi_window_show (myIcon->pAppli);
+				}
+				else
+				{
+					_cd_musicplayer_show_from_systray (NULL, NULL);
 				}
-				else if (myData.pCurrentHandler->launch != NULL)
-                              	  cairo_dock_launch_command (myData.pCurrentHandler->launch);
 			}
-			else if (myData.pCurrentHandler->launch != NULL)
-				cairo_dock_launch_command (myData.pCurrentHandler->launch);
+			else
+			{
+				if (myIcon->cClass != NULL)
+					gldi_icon_launch_command (myIcon);
+				else if (myData.pCurrentHandler->pAppInfo)
+					gldi_app_info_launch (myData.pCurrentHandler->pAppInfo, NULL);
+			}
 		}
 	}
 	else
@@ -259,52 +294,68 @@ CD_APPLET_ON_CLICK_END
 CD_APPLET_ON_BUILD_MENU_BEGIN
 	if (! myData.bIsRunning)
 	{
-		CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Find opened player"), GTK_STOCK_FIND, _cd_musicplayer_find_player, CD_APPLET_MY_MENU);
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Find opened player"), GLDI_ICON_NAME_FIND, _cd_musicplayer_find_player, CD_APPLET_MY_MENU);
 		if (myData.pCurrentHandler != NULL)
-			CD_APPLET_ADD_IN_MENU_WITH_STOCK (myData.pCurrentHandler->cDisplayedName?myData.pCurrentHandler->cDisplayedName:myData.pCurrentHandler->name, GTK_STOCK_MEDIA_PLAY, _cd_musicplayer_launch, CD_APPLET_MY_MENU);
+			CD_APPLET_ADD_IN_MENU_WITH_STOCK (myData.pCurrentHandler->cDisplayedName?myData.pCurrentHandler->cDisplayedName:myData.pCurrentHandler->name, GLDI_ICON_NAME_MEDIA_PLAY, _cd_musicplayer_launch, CD_APPLET_MY_MENU);
 		else
-			CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Choose a player"), GTK_STOCK_INDEX, _cd_musicplayer_choose_player, CD_APPLET_MY_MENU);
+			CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Choose a player"), GLDI_ICON_NAME_MEDIA_PLAY, _cd_musicplayer_choose_player, CD_APPLET_MY_MENU);
 	}
 	else
 	{
 		if (myData.pCurrentHandler->iPlayerControls & PLAYER_PREVIOUS)
 		{
 			gchar *cLabel = g_strdup_printf ("%s (%s)", D_("Previous"), D_("scroll-up"));
-			CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel, GTK_STOCK_MEDIA_PREVIOUS, _cd_musicplayer_prev, CD_APPLET_MY_MENU);
+			CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel, GLDI_ICON_NAME_MEDIA_PREVIOUS, _cd_musicplayer_prev, CD_APPLET_MY_MENU);
 			g_free (cLabel);
 		}
 		if (myData.pCurrentHandler->iPlayerControls & PLAYER_PLAY_PAUSE)
 		{
 			gchar *cLabel = g_strdup_printf ("%s (%s)", D_("Play/Pause"), myConfig.bPauseOnClick ? D_("left-click") : D_("middle-click"));
-			CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel, (myData.iPlayingStatus != PLAYER_PLAYING ? GTK_STOCK_MEDIA_PLAY : GTK_STOCK_MEDIA_PAUSE), _cd_musicplayer_pp, CD_APPLET_MY_MENU);
+			CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel, (myData.iPlayingStatus != PLAYER_PLAYING ? GLDI_ICON_NAME_MEDIA_PLAY : GLDI_ICON_NAME_MEDIA_PAUSE), _cd_musicplayer_pp, CD_APPLET_MY_MENU);
 			g_free (cLabel);
 		}
 		if (myData.pCurrentHandler->iPlayerControls & PLAYER_NEXT)
 		{
 			gchar *cLabel = g_strdup_printf ("%s (%s)", D_("Next"), D_("scroll-down"));
-			CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel, GTK_STOCK_MEDIA_NEXT, _cd_musicplayer_next, CD_APPLET_MY_MENU);
+			CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel, GLDI_ICON_NAME_MEDIA_NEXT, _cd_musicplayer_next, CD_APPLET_MY_MENU);
 			g_free (cLabel);
 		}
 		if (myData.pCurrentHandler->iPlayerControls & PLAYER_STOP)
-			CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Stop"), GTK_STOCK_MEDIA_STOP, _cd_musicplayer_stop, CD_APPLET_MY_MENU);
+			CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Stop"), GLDI_ICON_NAME_MEDIA_STOP, _cd_musicplayer_stop, CD_APPLET_MY_MENU);
 		
 		CD_APPLET_ADD_SEPARATOR_IN_MENU (CD_APPLET_MY_MENU);  // on n'a jamais zero action, donc on met toujours un separateur.
 		
-		CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Information"), GTK_STOCK_INFO, _cd_musicplayer_info, CD_APPLET_MY_MENU);
-
-		if (myIcon->Xid == 0)  // lecteur dans le systray.
-			CD_APPLET_ADD_IN_MENU (D_("Show the Window"), _cd_musicplayer_show_from_systray, CD_APPLET_MY_MENU);
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Information"), GLDI_ICON_NAME_INFO, _cd_musicplayer_info, CD_APPLET_MY_MENU);
 		
 		CD_APPLET_ADD_SEPARATOR_IN_MENU (CD_APPLET_MY_MENU);
 		
 		if (myData.pCurrentHandler->iPlayerControls & PLAYER_JUMPBOX)
 			CD_APPLET_ADD_IN_MENU (D_("Show JumpBox"), _cd_musicplayer_jumpbox, CD_APPLET_MY_MENU);
 		if (myData.pCurrentHandler->iPlayerControls & PLAYER_SHUFFLE)
-			CD_APPLET_ADD_IN_MENU (D_("Toggle Shuffle"), _cd_musicplayer_shuffle, CD_APPLET_MY_MENU);
+		{
+			pMenuItem = gtk_check_menu_item_new_with_label (D_("Shuffle"));
+			gboolean bIsShuffle = (myData.pCurrentHandler->get_shuffle_status ? myData.pCurrentHandler->get_shuffle_status() : FALSE);
+			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (pMenuItem), bIsShuffle);
+			gtk_menu_shell_append  (GTK_MENU_SHELL (CD_APPLET_MY_MENU), pMenuItem);
+			g_signal_connect (G_OBJECT (pMenuItem), "toggled", G_CALLBACK (_cd_musicplayer_shuffle), NULL);
+		}
 		if (myData.pCurrentHandler->iPlayerControls & PLAYER_REPEAT)
-			CD_APPLET_ADD_IN_MENU (D_("Toggle Repeat"), _cd_musicplayer_repeat, CD_APPLET_MY_MENU);
+		{
+			pMenuItem = gtk_check_menu_item_new_with_label (D_("Repeat"));
+			gboolean bIsLoop = (myData.pCurrentHandler->get_loop_status ? myData.pCurrentHandler->get_loop_status() : FALSE);
+			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (pMenuItem), bIsLoop);
+			gtk_menu_shell_append  (GTK_MENU_SHELL (CD_APPLET_MY_MENU), pMenuItem);
+			g_signal_connect (G_OBJECT (pMenuItem), "toggled", G_CALLBACK (_cd_musicplayer_repeat), NULL);
+		}
+		
 		if (myData.pCurrentHandler->iPlayerControls & PLAYER_RATE)
 			CD_APPLET_ADD_IN_MENU (D_("Rate this song"), _cd_musicplayer_rate, CD_APPLET_MY_MENU);
+		
+		if (myIcon->pAppli == NULL)  // player in the systray.
+		{
+			CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Show"), GLDI_ICON_NAME_FIND, _cd_musicplayer_show_from_systray, CD_APPLET_MY_MENU);
+			CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Quit"), GLDI_ICON_NAME_CLOSE, _cd_musicplayer_quit, CD_APPLET_MY_MENU);  // GLDI_ICON_NAME_QUIT looks too much like the "quit" of the dock.
+		}
 	}
 CD_APPLET_ON_BUILD_MENU_END
 
@@ -456,7 +507,7 @@ CD_APPLET_ON_UPDATE_ICON_BEGIN
 CD_APPLET_ON_UPDATE_ICON_END
 
 
-gboolean cd_opengl_test_mouse_over_buttons (CairoDockModuleInstance *myApplet, CairoContainer *pContainer, gboolean *bStartAnimation)
+gboolean cd_opengl_test_mouse_over_buttons (GldiModuleInstance *myApplet, GldiContainer *pContainer, gboolean *bStartAnimation)
 {
 	CD_APPLET_ENTER;
 	int iPrevButtonState = myData.iButtonState;
@@ -466,5 +517,5 @@ gboolean cd_opengl_test_mouse_over_buttons (CairoDockModuleInstance *myApplet, C
 	{
 		*bStartAnimation = TRUE;  // ca c'est pour faire une animation de transition...
 	}
-	CD_APPLET_LEAVE (CAIRO_DOCK_LET_PASS_NOTIFICATION);
+	CD_APPLET_LEAVE (GLDI_NOTIFICATION_LET_PASS);
 }
